@@ -121,7 +121,7 @@ start_routine(CLIENT *client)
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &state);
 #endif/*SIGNAL_CLIENT_PLATFORM*/ 
   if (my.login == TRUE) {
-    URL tmp = new_url(array_get(my.lurl, 0));
+    URL tmp = new_url(array_next(my.lurl));
     url_set_ID(tmp, 0);
     __request(C, tmp, client);
   }
