@@ -170,9 +170,15 @@ http_get(CONN *C, URL U)
     }
   }
 
-  /* Only send the Host header if one wasn't provided. */
+  /* Only send the Host header if one wasn't provided by the configuration. */
   if (strncasestr(my.extra, "host:", sizeof(my.extra)) == NULL) {
-    rlen = snprintf(hoststr, sizeof(hoststr), "Host: %s\015\012", url_get_hostname(U));
+    // as per RFC2616 14.23, send the port if it's not default
+    if ((url_get_scheme(U) == HTTP  && url_get_port(U) != 80) || 
+        (url_get_scheme(U) == HTTPS && url_get_port(U) != 443)) {
+      rlen = snprintf(hoststr, sizeof(hoststr), "Host: %s:%d\015\012", url_get_hostname(U), url_get_port(U));
+    } else {
+      rlen = snprintf(hoststr, sizeof(hoststr), "Host: %s\015\012", url_get_hostname(U));
+    }
   }
 
   mlen = strlen(url_get_method_name(U)) +
@@ -322,9 +328,15 @@ http_post(CONN *C, URL U)
     }
   }
 
-  /* Only send the Host header if one wasn't provided. */
+  /* Only send the Host header if one wasn't provided by the configuration. */
   if (strncasestr(my.extra, "host:", sizeof(my.extra)) == NULL) {
-    rlen = snprintf(hoststr, sizeof(hoststr), "Host: %s\015\012", url_get_hostname(U));
+    // as per RFC2616 14.23, send the port if it's not default
+    if ((url_get_scheme(U) == HTTP  && url_get_port(U) != 80) ||
+        (url_get_scheme(U) == HTTPS && url_get_port(U) != 443)) {
+      rlen = snprintf(hoststr, sizeof(hoststr), "Host: %s:%d\015\012", url_get_hostname(U), url_get_port(U));
+    } else {
+      rlen = snprintf(hoststr, sizeof(hoststr), "Host: %s\015\012", url_get_hostname(U));
+    }
   }
 
   mlen = strlen(url_get_method_name(U)) +
