@@ -78,9 +78,9 @@ write_to_log(int count, float elapsed, int bytes, float ttime, int code, int fai
     puts("the directive \'show-logfile\' to false." );
   }
 
-  if(!file_exists(my.logfile)){
-    if(!create_logfile(my.logfile)){
-      NOTIFY(ERROR, "unable to create log file");
+  if (!file_exists(my.logfile)) {
+    if (!create_logfile(my.logfile)) {
+      NOTIFY(ERROR, "unable to create log file: %s", my.logfile);
       return;
     }
   }
@@ -94,8 +94,8 @@ write_to_log(int count, float elapsed, int bytes, float ttime, int code, int fai
   );
 
   /* open the log and write to file */
-  if((fd = open( my.logfile, O_WRONLY | O_APPEND, 0644 )) < 0){
-    NOTIFY(ERROR, "Unable to write to file");
+  if ((fd = open( my.logfile, O_WRONLY | O_APPEND, 0644 )) < 0) {
+    NOTIFY(ERROR, "Unable to write to file: %s", my.logfile);
     return;
   }
 
@@ -115,9 +115,9 @@ mark_log_file(char *message)
   char entry[512];
 
   /* if the file does NOT exist then create it.  */
-  if(!file_exists(my.logfile)){
-    if(!create_logfile(my.logfile)){
-      NOTIFY(ERROR, "unable to create log file");
+  if (!file_exists(my.logfile)) {
+    if (!create_logfile(my.logfile)) {
+      NOTIFY(ERROR, "unable to create log file: %s", my.logfile);
       return;
     }
   }
@@ -126,7 +126,7 @@ mark_log_file(char *message)
   snprintf(entry, sizeof entry, "**** %s ****\n", message);
 
   if ((fd = open( my.logfile, O_WRONLY | O_APPEND, 0644 )) < 0) {
-    NOTIFY(ERROR, "Unable to write to file" );
+    NOTIFY(ERROR, "Unable to write to file: %s", my.logfile);
   }
 
   write(fd, entry, strlen(entry));
