@@ -1,7 +1,7 @@
 /**
  * Siege, http regression tester / benchmark utility
  *
- * Copyright (C) 2000-2013 by  
+ * Copyright (C) 2000-2014 by  
  * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege
  *
@@ -294,6 +294,7 @@ int
 main(int argc, char *argv[])
 {
   int            x; 
+  int            j = 0;
   int            result;
   DATA           D    = new_data();
   ARRAY          urls = new_array();
@@ -341,9 +342,9 @@ main(int argc, char *argv[])
     my.length = read_cfg_file(lines, my.file); 
   }
 
-  if (my.reps < 0) {
-    my.reps = my.length;
-  }
+  //if (my.reps < 0) {
+  //  my.reps = my.length;
+  //}
 
   if (my.length == 0) { 
     display_help();
@@ -449,7 +450,27 @@ main(int argc, char *argv[])
     client[x].code            = 0;
     client[x].ok200           = 0;   
     client[x].fail            = 0; 
-    client[x].urls            = urls;
+    if (my.reps > 0 ) {
+      /** 
+       * Traditional -r/--reps where each user
+       * loops through every URL in the file. 
+       */
+      client[x].urls = urls;
+    } else {
+      /**
+       * -r once/--reps=once where each URL
+       * in the file is hit only once...
+       */
+      int   len = (array_length(urls)/my.cusers); 
+      ARRAY tmp = new_array();
+      for ( ; j < ((x+1) * len) && j < (int)array_length(urls); j++) {
+        URL u = array_get(urls, j);
+        if (u != NULL && url_get_hostname(u) != NULL && strlen(url_get_hostname(u)) > 1) {
+          array_npush(tmp, array_get(urls, j), URLSIZE);    
+        }
+      } 
+      client[x].urls = tmp;
+    }
     client[x].auth.www        = 0;
     client[x].auth.proxy      = 0;
     client[x].auth.type.www   = BASIC;
