@@ -68,6 +68,10 @@ SSL_initialize(CONN *C)
 #ifdef HAVE_SSL
   int  i;
   int  serr;
+
+  if (C->ssl) {
+    return TRUE;
+  }
   
   C->ssl    = NULL;
   C->ctx    = NULL;
