@@ -459,6 +459,15 @@ url_normalize(URL req, char *location)
     // XXX: do I really need to test for localhost?
   }
 
+  // XXX: 8/20/2014 - YES. Yes, I do.
+  if (strstr(location, "localhost") != NULL) {
+    ret = new_url(location);
+    if (strlen(url_get_hostname(ret)) == 9) {
+      // we found and correctly parsed localhost
+      return ret;
+    }
+  }
+
   /**
    * If we got this far we better construct it...
    */
